@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
@@ -31,3 +32,17 @@ func TestTransformCronJob(t *testing.T) {
 	AssertEqual("schedule", node.Properties["schedule"], "30 23 * * *", t)
 	AssertEqual("suspend", node.Properties["suspend"], false, t)
 }
+
+func TestCronJobBuildEdges(t *testing.T) {
+	// Build a fake NodeStore with nodes needed to generate edges.
+	nodes := make([]Node, 0)
+	nodeStore := BuildFakeNodeStore(nodes)
+
+	// Build edges from mock resource cronjob.json
+	var cron v1.CronJob
+	UnmarshalFile("cronjob.json", &cron, t)
+	edges := CronJobResourceBuilder(&cron).BuildEdges(nodeStore)
+
+	// Validate results
+	AssertEqual("CronJob has no edges:", len(edges), 0, t)
+}
