@@ -6,11 +6,12 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
 import (
-	app "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	app "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
 )
 
 // PlacementRuleResource ...
